package com.os.ems.info.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.info.domain.DailyFaultRecord;
import com.os.ems.info.service.IDailyFaultRecordService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 日常故障记录Controller
 * 
 * @author Yinq
 * @date 2025-06-05
 */
@RestController
@RequestMapping("/ems/info/dailyFaultRecord")
public class DailyFaultRecordController extends BaseController
{
    @Autowired
    private IDailyFaultRecordService dailyFaultRecordService;

    /**
     * 查询日常故障记录列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:dailyFaultRecord:list')")
    @GetMapping("/list")
    public TableDataInfo list(DailyFaultRecord dailyFaultRecord)
    {
        startPage();
        List<DailyFaultRecord> list = dailyFaultRecordService.selectDailyFaultRecordList(dailyFaultRecord);
        return getDataTable(list);
    }

    /**
     * 导出日常故障记录列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:dailyFaultRecord:export')")
    @Log(title = "日常故障记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DailyFaultRecord dailyFaultRecord)
    {
        List<DailyFaultRecord> list = dailyFaultRecordService.selectDailyFaultRecordList(dailyFaultRecord);
        ExcelUtil<DailyFaultRecord> util = new ExcelUtil<DailyFaultRecord>(DailyFaultRecord.class);
        util.exportExcel(response, list, "日常故障记录数据");
    }

    /**
     * 获取日常故障记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/info:dailyFaultRecord:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dailyFaultRecordService.selectDailyFaultRecordById(id));
    }

    /**
     * 新增日常故障记录
     */
    @PreAuthorize("@ss.hasPermi('ems/info:dailyFaultRecord:add')")
    @Log(title = "日常故障记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DailyFaultRecord dailyFaultRecord)
    {
        dailyFaultRecord.setCreateBy(getUsername());
        return toAjax(dailyFaultRecordService.insertDailyFaultRecord(dailyFaultRecord));
    }

    /**
     * 修改日常故障记录
     */
    @PreAuthorize("@ss.hasPermi('ems/info:dailyFaultRecord:edit')")
    @Log(title = "日常故障记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DailyFaultRecord dailyFaultRecord)
    {
        dailyFaultRecord.setUpdateBy(getUsername());
        return toAjax(dailyFaultRecordService.updateDailyFaultRecord(dailyFaultRecord));
    }

    /**
     * 删除日常故障记录
     */
    @PreAuthorize("@ss.hasPermi('ems/info:dailyFaultRecord:remove')")
    @Log(title = "日常故障记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dailyFaultRecordService.deleteDailyFaultRecordByIds(ids));
    }

    /**
     * 导入日常故障记录数据
     */
    @PreAuthorize("@ss.hasPermi('ems/info:dailyFaultRecord:add')")
    @Log(title = "日常故障记录", businessType = BusinessType.IMPORT)
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception
    {
        ExcelUtil<DailyFaultRecord> util = new ExcelUtil<DailyFaultRecord>(DailyFaultRecord.class);
        List<DailyFaultRecord> recordList = util.importExcel(file.getInputStream());
        String operName = getUsername();
        String message = dailyFaultRecordService.importDailyFaultRecord(recordList, updateSupport, operName);
        return AjaxResult.success(message);
    }

    /**
     * 获取日常故障记录导入模板
     */
    @PostMapping("/importTemplate")
    public AjaxResult importTemplate()
    {
        ExcelUtil<DailyFaultRecord> util = new ExcelUtil<DailyFaultRecord>(DailyFaultRecord.class);
        return util.importTemplateExcel("日常故障记录数据");
    }
}
