package com.os.ems.info.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.info.domain.LuggageSystemPlcBufferBatteryLifecycle;
import com.os.ems.info.service.ILuggageSystemPlcBufferBatteryLifecycleService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 行李系统PLC缓冲电池生命周期Controller
 * 
 * @author Yinq
 * @date 2025-06-05
 */
@RestController
@RequestMapping("/ems/info/plcBufferBatteryLifecycle")
public class LuggageSystemPlcBufferBatteryLifecycleController extends BaseController
{
    @Autowired
    private ILuggageSystemPlcBufferBatteryLifecycleService luggageSystemPlcBufferBatteryLifecycleService;

    /**
     * 查询行李系统PLC缓冲电池生命周期列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:plcBufferBatteryLifecycle:list')")
    @GetMapping("/list")
    public TableDataInfo list(LuggageSystemPlcBufferBatteryLifecycle luggageSystemPlcBufferBatteryLifecycle)
    {
        startPage();
        List<LuggageSystemPlcBufferBatteryLifecycle> list = luggageSystemPlcBufferBatteryLifecycleService.selectLuggageSystemPlcBufferBatteryLifecycleList(luggageSystemPlcBufferBatteryLifecycle);
        return getDataTable(list);
    }

    /**
     * 导出行李系统PLC缓冲电池生命周期列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:plcBufferBatteryLifecycle:export')")
    @Log(title = "行李系统PLC缓冲电池生命周期", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LuggageSystemPlcBufferBatteryLifecycle luggageSystemPlcBufferBatteryLifecycle)
    {
        List<LuggageSystemPlcBufferBatteryLifecycle> list = luggageSystemPlcBufferBatteryLifecycleService.selectLuggageSystemPlcBufferBatteryLifecycleList(luggageSystemPlcBufferBatteryLifecycle);
        ExcelUtil<LuggageSystemPlcBufferBatteryLifecycle> util = new ExcelUtil<LuggageSystemPlcBufferBatteryLifecycle>(LuggageSystemPlcBufferBatteryLifecycle.class);
        util.exportExcel(response, list, "行李系统PLC缓冲电池生命周期数据");
    }

    /**
     * 获取行李系统PLC缓冲电池生命周期详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/info:plcBufferBatteryLifecycle:query')")
    @GetMapping(value = "/{objid}")
    public AjaxResult getInfo(@PathVariable("objid") Long objid)
    {
        return success(luggageSystemPlcBufferBatteryLifecycleService.selectLuggageSystemPlcBufferBatteryLifecycleByObjid(objid));
    }

    /**
     * 新增行李系统PLC缓冲电池生命周期
     */
    @PreAuthorize("@ss.hasPermi('ems/info:plcBufferBatteryLifecycle:add')")
    @Log(title = "行李系统PLC缓冲电池生命周期", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LuggageSystemPlcBufferBatteryLifecycle luggageSystemPlcBufferBatteryLifecycle)
    {
        luggageSystemPlcBufferBatteryLifecycle.setCreateBy(getUsername());
        return toAjax(luggageSystemPlcBufferBatteryLifecycleService.insertLuggageSystemPlcBufferBatteryLifecycle(luggageSystemPlcBufferBatteryLifecycle));
    }

    /**
     * 修改行李系统PLC缓冲电池生命周期
     */
    @PreAuthorize("@ss.hasPermi('ems/info:plcBufferBatteryLifecycle:edit')")
    @Log(title = "行李系统PLC缓冲电池生命周期", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LuggageSystemPlcBufferBatteryLifecycle luggageSystemPlcBufferBatteryLifecycle)
    {
        luggageSystemPlcBufferBatteryLifecycle.setUpdateBy(getUsername());
        return toAjax(luggageSystemPlcBufferBatteryLifecycleService.updateLuggageSystemPlcBufferBatteryLifecycle(luggageSystemPlcBufferBatteryLifecycle));
    }

    /**
     * 删除行李系统PLC缓冲电池生命周期
     */
    @PreAuthorize("@ss.hasPermi('ems/info:plcBufferBatteryLifecycle:remove')")
    @Log(title = "行李系统PLC缓冲电池生命周期", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objids}")
    public AjaxResult remove(@PathVariable Long[] objids)
    {
        return toAjax(luggageSystemPlcBufferBatteryLifecycleService.deleteLuggageSystemPlcBufferBatteryLifecycleByObjids(objids));
    }

    /**
     * 导入行李系统PLC缓冲电池生命周期数据
     */
    @PreAuthorize("@ss.hasPermi('ems/info:plcBufferBatteryLifecycle:add')")
    @Log(title = "行李系统PLC缓冲电池生命周期", businessType = BusinessType.IMPORT)
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, @RequestParam(value = "updateSupport", defaultValue = "false") boolean updateSupport) throws Exception
    {
        ExcelUtil<LuggageSystemPlcBufferBatteryLifecycle> util = new ExcelUtil<LuggageSystemPlcBufferBatteryLifecycle>(LuggageSystemPlcBufferBatteryLifecycle.class);
        List<LuggageSystemPlcBufferBatteryLifecycle> dataList = util.importExcel(file.getInputStream());
        String message = luggageSystemPlcBufferBatteryLifecycleService.importLuggageSystemPlcBufferBatteryLifecycle(dataList, updateSupport, getUsername());
        return AjaxResult.success(message);
    }

    /**
     * 获取行李系统PLC缓冲电池生命周期导入模板
     */
    @PreAuthorize("@ss.hasPermi('ems/info:plcBufferBatteryLifecycle:add')")
    @PostMapping("/importTemplate")
    public AjaxResult importTemplate()
    {
        ExcelUtil<LuggageSystemPlcBufferBatteryLifecycle> util = new ExcelUtil<LuggageSystemPlcBufferBatteryLifecycle>(LuggageSystemPlcBufferBatteryLifecycle.class);
        return util.importTemplateExcel("行李系统PLC缓冲电池生命周期数据");
    }
}
