package com.os.ems.info.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.info.domain.SparePartsInventoryCheck;
import com.os.ems.info.service.ISparePartsInventoryCheckService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 备件盘点记录明细Controller
 * 
 * @author Yinq
 * @date 2024-12-13
 */
@RestController
@RequestMapping("/ems/info/sparePartsInventoryCheck")
public class SparePartsInventoryCheckController extends BaseController
{
    @Autowired
    private ISparePartsInventoryCheckService sparePartsInventoryCheckService;

    /**
     * 查询备件盘点记录明细列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsInventoryCheck:list')")
    @GetMapping("/list")
    public TableDataInfo list(SparePartsInventoryCheck sparePartsInventoryCheck)
    {
        startPage();
        List<SparePartsInventoryCheck> list = sparePartsInventoryCheckService.selectSparePartsInventoryCheckList(sparePartsInventoryCheck);
        return getDataTable(list);
    }

    /**
     * 导出备件盘点记录明细列表
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsInventoryCheck:export')")
    @Log(title = "备件盘点记录明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SparePartsInventoryCheck sparePartsInventoryCheck)
    {
        List<SparePartsInventoryCheck> list = sparePartsInventoryCheckService.selectSparePartsInventoryCheckList(sparePartsInventoryCheck);
        ExcelUtil<SparePartsInventoryCheck> util = new ExcelUtil<SparePartsInventoryCheck>(SparePartsInventoryCheck.class);
        util.exportExcel(response, list, "备件盘点记录明细数据");
    }

    /**
     * 获取备件盘点记录明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsInventoryCheck:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sparePartsInventoryCheckService.selectSparePartsInventoryCheckById(id));
    }

    /**
     * 新增备件盘点记录明细
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsInventoryCheck:add')")
    @Log(title = "备件盘点记录明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SparePartsInventoryCheck sparePartsInventoryCheck)
    {
        sparePartsInventoryCheck.setCreateBy(getUsername());
        return toAjax(sparePartsInventoryCheckService.insertSparePartsInventoryCheck(sparePartsInventoryCheck));
    }

    /**
     * 修改备件盘点记录明细
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsInventoryCheck:edit')")
    @Log(title = "备件盘点记录明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SparePartsInventoryCheck sparePartsInventoryCheck)
    {
        sparePartsInventoryCheck.setUpdateBy(getUsername());
        return toAjax(sparePartsInventoryCheckService.updateSparePartsInventoryCheck(sparePartsInventoryCheck));
    }

    /**
     * 删除备件盘点记录明细
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsInventoryCheck:remove')")
    @Log(title = "备件盘点记录明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sparePartsInventoryCheckService.deleteSparePartsInventoryCheckByIds(ids));
    }

    /**
     * 导入备件盘点记录明细数据
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsInventoryCheck:add')")
    @Log(title = "备件盘点记录明细", businessType = BusinessType.IMPORT)
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file, @RequestParam(value = "updateSupport", defaultValue = "false") boolean updateSupport) throws Exception
    {
        ExcelUtil<SparePartsInventoryCheck> util = new ExcelUtil<SparePartsInventoryCheck>(SparePartsInventoryCheck.class);
        List<SparePartsInventoryCheck> dataList = util.importExcel(file.getInputStream());
        String message = sparePartsInventoryCheckService.importSparePartsInventoryCheck(dataList, updateSupport, getUsername());
        return AjaxResult.success(message);
    }

    /**
     * 获取备件盘点记录明细导入模板
     */
    @PreAuthorize("@ss.hasPermi('ems/info:sparePartsInventoryCheck:add')")
    @PostMapping("/importTemplate")
    public AjaxResult importTemplate()
    {
        ExcelUtil<SparePartsInventoryCheck> util = new ExcelUtil<SparePartsInventoryCheck>(SparePartsInventoryCheck.class);
        return util.importTemplateExcel("备件盘点记录明细数据");
    }
}
