package com.os.ems.info.service.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.os.ems.info.mapper.CommonClearMapper;
import com.os.ems.info.service.ICommonClearService;

/**
 * 通用数据清空Service业务层处理
 * 
 * @author System
 * @date 2025-01-20
 */
@Service
public class CommonClearServiceImpl implements ICommonClearService 
{
    @Autowired
    private CommonClearMapper commonClearMapper;

    /**
     * 清空指定表的所有数据
     * 使用事务确保数据一致性
     * 
     * @param tableName 表名（已通过白名单验证）
     * @return 删除的记录数
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int clearTableData(String tableName)
    {
        // 表名已在Controller层通过白名单验证，这里直接执行
        return commonClearMapper.clearTableData(tableName);
    }
    
    /**
     * 清空指定表的所有数据（支持级联删除）
     * 使用事务确保数据一致性
     * 
     * @param tableName 主表名
     * @param moduleKey 业务模块标识
     * @return 删除的记录数
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int clearTableDataWithCascade(String tableName, String moduleKey)
    {
        int totalDeleted = 0;
        
        // 根据模块标识进行特殊处理
        if ("sparePartsInventory".equals(moduleKey)) {
            // 备件库记录：先删除明细表，再删除主表
            // 1. 删除备件盘点记录明细表
            int detailDeleted = commonClearMapper.clearTableData("spare_parts_inventory_check");
            totalDeleted += detailDeleted;
            
            // 2. 删除备件库记录主表
            int mainDeleted = commonClearMapper.clearTableData("spare_parts_inventory");
            totalDeleted += mainDeleted;
            
            return totalDeleted;
        } else {
            // 其他模块使用普通删除
            return commonClearMapper.clearTableData(tableName);
        }
    }
} 