package com.os.mes.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.base.domain.BaseTeamMembers;
import com.os.mes.base.service.IBaseTeamMembersService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 班组信息Controller
 *
 * @author Yinq
 * @date 2024-05-15
 */
@RestController
@RequestMapping("/mes/base/baseTeamMembers")
public class BaseTeamMembersController extends BaseController {
    @Autowired
    private IBaseTeamMembersService baseTeamMembersService;

    /**
     * 查询班组信息列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseTeamMembers:list')")
    @GetMapping("/list")
    public TableDataInfo list(BaseTeamMembers baseTeamMembers) {
        startPage();
        List<BaseTeamMembers> list = baseTeamMembersService.selectBaseTeamMembersList(baseTeamMembers);
        return getDataTable(list);
    }

    /**
     * 查询班组信息下拉框列表
     */
    @GetMapping("/getTeamMembers")
    public AjaxResult getTeamMembers(BaseTeamMembers baseTeamMembers) {
        List<BaseTeamMembers> list = baseTeamMembersService.selectBaseTeamMembersList(baseTeamMembers);
        return success(list);
    }

    /**
     * 导出班组信息列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseTeamMembers:export')")
    @Log(title = "班组信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseTeamMembers baseTeamMembers) {
        List<BaseTeamMembers> list = baseTeamMembersService.selectBaseTeamMembersList(baseTeamMembers);
        ExcelUtil<BaseTeamMembers> util = new ExcelUtil<BaseTeamMembers>(BaseTeamMembers.class);
        util.exportExcel(response, list, "班组信息数据");
    }

    /**
     * 获取班组信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseTeamMembers:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(baseTeamMembersService.selectBaseTeamMembersByObjId(objId));
    }

    /**
     * 新增班组信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseTeamMembers:add')")
    @Log(title = "班组信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseTeamMembers baseTeamMembers) {
        baseTeamMembers.setCreateBy(getUsername());
        return toAjax(baseTeamMembersService.insertBaseTeamMembers(baseTeamMembers));
    }

    /**
     * 修改班组信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseTeamMembers:edit')")
    @Log(title = "班组信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseTeamMembers baseTeamMembers) {
        baseTeamMembers.setUpdateBy(getUsername());
        return toAjax(baseTeamMembersService.updateBaseTeamMembers(baseTeamMembers));
    }

    /**
     * 删除班组信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseTeamMembers:remove')")
    @Log(title = "班组信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(baseTeamMembersService.deleteBaseTeamMembersByObjIds(objIds));
    }
}
