package com.os.mes.base.service.impl;

import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import com.os.common.utils.DateUtils;
import com.os.common.utils.StringUtils;
import com.os.mes.base.domain.BaseProductLine;
import com.os.mes.base.mapper.BaseProductLineMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.base.mapper.BaseProcessInfoMapper;
import com.os.mes.base.domain.BaseProcessInfo;
import com.os.mes.base.service.IBaseProcessInfoService;

/**
 * 工序信息Service业务层处理
 *
 * @author Yinq
 * @date 2024-05-23
 */
@Service
public class BaseProcessInfoServiceImpl implements IBaseProcessInfoService {
    @Autowired
    private BaseProcessInfoMapper baseProcessInfoMapper;

    @Autowired
    private BaseProductLineMapper baseProductLineMapper;

    /**
     * 查询工序信息
     *
     * @param objId 工序信息主键
     * @return 工序信息
     */
    @Override
    public BaseProcessInfo selectBaseProcessInfoByObjId(Long objId) {
        return baseProcessInfoMapper.selectBaseProcessInfoByObjId(objId);
    }

    /**
     * 查询工序信息列表
     *
     * @param baseProcessInfo 工序信息
     * @return 工序信息
     */
    @Override
    public List<BaseProcessInfo> selectBaseProcessInfoList(BaseProcessInfo baseProcessInfo) {
        List<BaseProcessInfo> processList = baseProcessInfoMapper.selectBaseProcessInfoList(baseProcessInfo);
        BaseProductLine productLine = new BaseProductLine();
        productLine.setProductLineType("2");
        List<BaseProductLine> stationList = baseProductLineMapper.selectBaseProductLineList(productLine);
        for (BaseProcessInfo processInfo : processList) {
            String stationCodes = processInfo.getStationCodes();
            if (StringUtils.isEmpty(stationCodes)) {
                continue;
            }
            String[] stationCodeList = stationCodes.split(",");
            for (String stationCode : stationCodeList) {
                List<BaseProductLine> baseProductLines = stationList.stream().filter(e -> Objects.equals(e.getProductLineCode(), stationCode)).collect(Collectors.toList());
                if (baseProductLines.size() > 0) {
                    String productLineName = baseProductLines.get(0).getProductLineName();
                    if (StringUtils.isEmpty(processInfo.getStationNames())) {
                        processInfo.setStationNames(productLineName);
                    } else {
                        processInfo.setStationNames(processInfo.getStationNames() + "," + productLineName);
                    }
                }
            }
        }
        return processList;
    }

    /**
     * 新增工序信息
     *
     * @param baseProcessInfo 工序信息
     * @return 结果
     */
    @Override
    public int insertBaseProcessInfo(BaseProcessInfo baseProcessInfo) {
        baseProcessInfo.setCreateTime(DateUtils.getNowDate());
        return baseProcessInfoMapper.insertBaseProcessInfo(baseProcessInfo);
    }

    /**
     * 修改工序信息
     *
     * @param baseProcessInfo 工序信息
     * @return 结果
     */
    @Override
    public int updateBaseProcessInfo(BaseProcessInfo baseProcessInfo) {
        baseProcessInfo.setUpdateTime(DateUtils.getNowDate());
        return baseProcessInfoMapper.updateBaseProcessInfo(baseProcessInfo);
    }

    /**
     * 批量删除工序信息
     *
     * @param objIds 需要删除的工序信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseProcessInfoByObjIds(Long[] objIds) {
        return baseProcessInfoMapper.deleteBaseProcessInfoByObjIds(objIds);
    }

    /**
     * 删除工序信息信息
     *
     * @param objId 工序信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseProcessInfoByObjId(Long objId) {
        return baseProcessInfoMapper.deleteBaseProcessInfoByObjId(objId);
    }
}
