package com.os.mes.prod.service.impl;

import java.math.BigDecimal;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.PropertyNamingStrategy;
import com.os.common.utils.DateUtils;
import com.os.common.utils.uuid.PlanCodeUtils;
import com.os.mes.api.domain.Material;
import com.os.mes.api.domain.RecordData;
import com.os.mes.api.domain.ResponseData;
import com.os.mes.api.domain.UpperLowerGlue;
import com.os.mes.prod.domain.ProdOrderDetail;
import com.os.mes.prod.domain.ProdPlanInfo;
import com.os.mes.prod.service.IProdOrderDetailService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.prod.mapper.ProdOrderInfoMapper;
import com.os.mes.prod.domain.ProdOrderInfo;
import com.os.mes.prod.service.IProdOrderInfoService;

/**
 * 订单信息Service业务层处理
 *
 * @author Yinq
 * @date 2024-05-17
 */
@Service
public class ProdOrderInfoServiceImpl implements IProdOrderInfoService {

    private static final Logger logger = LoggerFactory.getLogger(ProdOrderInfoServiceImpl.class);

    @Autowired
    private ProdOrderInfoMapper prodOrderInfoMapper;

    @Autowired
    private IProdOrderDetailService prodOrderDetailService;

    /**
     * 查询订单信息
     *
     * @param objId 订单信息主键
     * @return 订单信息
     */
    @Override
    public ProdOrderInfo selectProdOrderInfoByObjId(Long objId) {
        return prodOrderInfoMapper.selectProdOrderInfoByObjId(objId);
    }

    /**
     * 查询订单信息列表
     *
     * @param prodOrderInfo 订单信息
     * @return 订单信息
     */
    @Override
    public List<ProdOrderInfo> selectProdOrderInfoList(ProdOrderInfo prodOrderInfo) {
        return prodOrderInfoMapper.selectProdOrderInfoList(prodOrderInfo);
    }

    /**
     * 新增订单信息
     *
     * @param prodOrderInfo 订单信息
     * @return 结果
     */
    @Override
    public int insertProdOrderInfo(ProdOrderInfo prodOrderInfo) {
        prodOrderInfo.setCreatedTime(DateUtils.getNowDate());
        return prodOrderInfoMapper.insertProdOrderInfo(prodOrderInfo);
    }

    /**
     * 修改订单信息
     *
     * @param prodOrderInfo 订单信息
     * @return 结果
     */
    @Override
    public int updateProdOrderInfo(ProdOrderInfo prodOrderInfo) {
        prodOrderInfo.setUpdatedTime(DateUtils.getNowDate());
        return prodOrderInfoMapper.updateProdOrderInfo(prodOrderInfo);
    }

    /**
     * 批量删除订单信息
     *
     * @param objIds 需要删除的订单信息主键
     * @return 结果
     */
    @Override
    public int deleteProdOrderInfoByObjIds(Long[] objIds) {
        return prodOrderInfoMapper.deleteProdOrderInfoByObjIds(objIds);
    }

    /**
     * 删除订单信息信息
     *
     * @param objId 订单信息主键
     * @return 结果
     */
    @Override
    public int deleteProdOrderInfoByObjId(Long objId) {
        return prodOrderInfoMapper.deleteProdOrderInfoByObjId(objId);
    }

    /**
     * 通过ERP插入订单信息
     *
     * @param recordData
     */
    @Override
    public ProdOrderDetail insertOrderByERP(RecordData recordData) {
        ProdOrderInfo orderInfo = new ProdOrderInfo();
        ProdOrderDetail orderDetail = new ProdOrderDetail();
        //维护订单信息
        ProdOrderInfo selectOrder = new ProdOrderInfo();
        selectOrder.setOrderCode(recordData.getSeqNo());
        List<ProdOrderInfo> prodOrderInfos = this.selectProdOrderInfoList(selectOrder);

        orderInfo.setOrderCode(recordData.getSeqNo());
        //orderInfo.setMaterialCode(" ");
        orderInfo.setMaterialName(recordData.getBeltLengthSpecifications());
        orderInfo.setOrderType(recordData.getProductType());
        orderInfo.setOrderAmount(recordData.getBeltRequiredLength());
        try {
            orderInfo.setBeginDate(DateUtils.parseDate(recordData.getOrderDate(), DateUtils.parsePatterns));
            orderInfo.setEndDate(DateUtils.parseDate(recordData.getOrderDate(), DateUtils.parsePatterns));
        } catch (ParseException e) {
            e.printStackTrace();
        }

        if (prodOrderInfos.size() > 0) {
            orderInfo.setObjId(prodOrderInfos.get(0).getObjId());
            this.updateProdOrderInfo(orderInfo);
        }else {
            this.insertProdOrderInfo(orderInfo);
        }
        //维护订单明细
        ProdOrderDetail selectOrderDetail = new ProdOrderDetail();
        selectOrderDetail.setSeqNo(recordData.getSeqNo());
        List<ProdOrderDetail> prodOrderDetails = prodOrderDetailService.selectProdOrderDetailList(selectOrderDetail);
        orderDetail.setSeqNo(recordData.getSeqNo());  // 任务编号
        orderDetail.setOrderDate(recordData.getOrderDate());  // 下单日期
        orderDetail.setDeliveryDate(recordData.getDeliveryDate());  // 交货日期
        orderDetail.setProductType(recordData.getProductType());  // 产品类型
        orderDetail.setProductStatus(recordData.getProductStatus());  // 产品状态
        orderDetail.setOrderOwner(recordData.getOrderOwner());  // 订单所属
        orderDetail.setCustomerInfo(recordData.getCustomerInfo());  // 客户信息
        orderDetail.setBeltLengthSpecifications(recordData.getBeltLengthSpecifications());  // 输送带长度规格
        orderDetail.setAreaAndWeight(recordData.getAreaAndWeight());  // 面积与重量
        orderDetail.setUsingRawMaterials(recordData.getUsingRawMaterials());  // 使用原材料
        orderDetail.setBeltWidth(recordData.getBeltWidth());  // 输送带宽度（mm）
        orderDetail.setBeltClothLayer(recordData.getBeltClothLayer());  // 输送带布层
        orderDetail.setBeltRequiredLength(recordData.getBeltRequiredLength());  // 客户要求输送带长度（m）
        orderDetail.setGluingRequiredThickness(recordData.getGluingRequiredThickness());  // 客户要求上胶厚度（mm）
        orderDetail.setLowerGlueRequiredThickness(recordData.getLowerGlueRequiredThickness());  // 客户要求下胶厚度（mm）
        orderDetail.setProductionGluingThickness(recordData.getProductionGluingThickness());  // 生产上胶厚度（mm）
        orderDetail.setUpperBufferAdhesiveThickness(recordData.getUpperBufferAdhesiveThickness());  // 上缓冲胶厚度（mm）
        orderDetail.setProductionLowerGlueThickness(recordData.getProductionLowerGlueThickness());  // 生产下胶厚度（mm）
        orderDetail.setLowerBufferAdhesiveThickness(recordData.getLowerBufferAdhesiveThickness());  // 下缓冲胶厚度（mm）
        orderDetail.setClothGlueThickness(recordData.getClothGlueThickness());  // 布胶厚度
        orderDetail.setSmallClothFabricLayer(recordData.getSmallClothFabricLayer());  // 小布用布布层
        orderDetail.setSmallClothThickness(recordData.getSmallClothThickness());  // 小布布料厚度（mm）
        orderDetail.setIsNeedThicken(recordData.getIsNeedThicken());  // 是否需要每层加厚
        orderDetail.setEachLayerThickenThickness(recordData.getEachLayerThickenThickness());  // 每层加厚厚度（mm）
        orderDetail.setExtraThickeningThickness(recordData.getExtraThickeningThickness());  // 额外加厚厚度（mm）
        orderDetail.setTotalProductionThickness(recordData.getTotalProductionThickness());  // 生产总厚度（mm）
        orderDetail.setAdditionalThickness(recordData.getAdditionalThickness());  // 压延追加厚度
        orderDetail.setRecommendedShimThickness(recordData.getRecommendedShimThickness());  // 推荐垫铁厚度（mm）
        orderDetail.setSemiFinishedProductWidth(recordData.getSemiFinishedProductWidth());  // 推荐半成品宽度（mm）
        orderDetail.setRollingProductionMeters(recordData.getRollingProductionMeters());  // 压延生产米数（m）
        orderDetail.setRecommendedPadWidth(recordData.getRecommendedPadWidth());  // 推荐垫布宽度（mm）
        orderDetail.setBigFabricManufacturer(recordData.getBigFabricManufacturer());  // 大布厂家
        try {
            ObjectMapper objectMapper = new ObjectMapper();
            objectMapper.setPropertyNamingStrategy(PropertyNamingStrategy.UPPER_CAMEL_CASE);
            orderDetail.setFabricSpecifications(objectMapper.writeValueAsString(recordData.getFabricSpecifications()));  // 布料规格
            orderDetail.setSmallFabricSpecificationsDic(objectMapper.writeValueAsString(recordData.getSmallFabricSpecificationsDic()));  // 小布使用布料规格
            orderDetail.setUpperLowerGlue(objectMapper.writeValueAsString(recordData.getUpperLowerGlue()));  // 上下胶使用胶料
            orderDetail.setLowerGlue(objectMapper.writeValueAsString(recordData.getLowerGlue()));  // 下胶使用胶料
            orderDetail.setLargeClothGlue(objectMapper.writeValueAsString(recordData.getLargeClothGlue()));  // 大布胶使用胶料
            orderDetail.setMiddleGlue(objectMapper.writeValueAsString(recordData.getMiddleGlue()));  // 中间胶
        } catch (Exception e) {
            logger.error("保存ERP订单接口日志错误：" + e.getMessage());
        }
        orderDetail.setEstimatedFabricUsage(recordData.getEstimatedFabricUsage());  // 预计布料使用量（m）
        orderDetail.setClothWidth(recordData.getClothWidth());  // 布宽度（mm）
        orderDetail.setClothWeight(recordData.getClothWeight());  // 布重量（kg）
        orderDetail.setSmallClothWidth(recordData.getSmallClothWidth());  // 小布宽度（mm）
        orderDetail.setSmallClothUsage(recordData.getSmallClothUsage());  // 小布布料使用量（m）
        orderDetail.setSmallClothWeight(recordData.getSmallClothWeight());  // 小布用布重量（kg）
        orderDetail.setGluingProcess(recordData.getGluingProcess());  // 用胶工艺
        orderDetail.setUpperLowerGlueCoefficient(recordData.getUpperLowerGlueCoefficient());  // 上下胶系数
        orderDetail.setUpperLowerGlueUsage(recordData.getUpperLowerGlueUsage());  // 上下胶标准用胶量（kg）
        orderDetail.setLowerGlueCoefficient(recordData.getLowerGlueCoefficient());  // 下胶系数
        orderDetail.setLowerGlueUsage(recordData.getLowerGlueUsage());  // 下胶标准用胶量（kg）
        orderDetail.setLargeClothGlueCoefficient(recordData.getLargeClothGlueCoefficient());  // 大布胶系数
        orderDetail.setLargeClothGlueUsage(recordData.getLargeClothGlueUsage());  // 胶布标准用胶量（kg）
        orderDetail.setBufferGlueUsage(recordData.getBufferGlueUsage());  // 上下缓冲胶标准用胶量（kg）
        orderDetail.setMiddleGlueCoefficient(recordData.getMiddleGlueCoefficient());  // 中间胶系数
        orderDetail.setMiddleGlueUsage(recordData.getMiddleGlueUsage());  // 中间胶使用量
        orderDetail.setSmallBarWidth(recordData.getSmallBarWidth());  // 小条宽度
        orderDetail.setSmallBarThickness(recordData.getSmallBarThickness());  // 小条厚度
        orderDetail.setSmallBarStandardUsage(recordData.getSmallBarStandardUsage());  // 小条标准使用量（kg）
        orderDetail.setFormingArea(recordData.getFormingArea());  // 成型面积
        orderDetail.setRollCoatingArea(recordData.getRollCoatingArea());  // 压延包胶面积
        orderDetail.setRolledFabricArea(recordData.getRolledFabricArea());  // 压延出布面积
        orderDetail.setSulfurizationArea(recordData.getSulfurizationArea());  // 硫化面积
        orderDetail.setLargeClothArea(recordData.getLargeClothArea());  // 大布面积
        orderDetail.setSmallClothArea(recordData.getSmallClothArea());  // 小布面积
        orderDetail.setBeltTotalArea(recordData.getBeltTotalArea());  // 输送带总面积
        orderDetail.setSkirtArea(recordData.getSkirtArea());  // 裙边面积
        orderDetail.setPartitionArea(recordData.getPartitionArea());  // 隔板面积
        orderDetail.setEdgeBandingTotalArea(recordData.getEdgeBandingTotalArea());  // 挡边带总面积
        orderDetail.setWireropeBeltTotalArea(recordData.getWireropeBeltTotalArea());  // 钢丝绳输送带工资总面积

        if (prodOrderDetails.size() > 0) {
            orderDetail.setObjId(prodOrderDetails.get(0).getObjId());
            orderDetail.setUpdateTime(DateUtils.getNowDate());  // 更新时间
            prodOrderDetailService.updateProdOrderDetail(orderDetail);
        } else {
            orderDetail.setCreateTime(DateUtils.getNowDate());  // 创建时间
            prodOrderDetailService.insertProdOrderDetail(orderDetail);
        }

        return orderDetail;
    }

    /**
     * 根据订单生成工单
     * @param prodOrderInfo
     * @return
     */
    @Override
    public HashMap<String, Object> generateWorkOrder(ProdOrderInfo prodOrderInfo) {
        HashMap<String, Object> result = new HashMap<>();
        List<ProdPlanInfo> planInfoList = new ArrayList<>();
        ProdOrderInfo prodOrder = prodOrderInfoMapper.selectProdOrderInfoByObjId(prodOrderInfo.getObjId());

        //布
        ProdPlanInfo clothPlan = new ProdPlanInfo();
        clothPlan.setOrderCode(prodOrder.getOrderCode());
        clothPlan.setPlanCode(PlanCodeUtils.getPlanCode());
        clothPlan.setPlanAmount(prodOrder.getOrderDetail().getEstimatedFabricUsage());
        try {
            String fabricSpecifications = prodOrder.getOrderDetail().getFabricSpecifications();
            ObjectMapper resultMapper = new ObjectMapper();
            Material material = resultMapper.readValue(fabricSpecifications, Material.class);
            clothPlan.setMaterialCode(material.getMaterialNo());
            clothPlan.setMaterialName(material.getMaterialName());
        } catch (Exception e) {
            e.printStackTrace();
        }

        //胶
        ProdPlanInfo gluePlan = new ProdPlanInfo();
        gluePlan.setOrderCode(prodOrder.getOrderCode());
        gluePlan.setPlanCode(PlanCodeUtils.getPlanCode());
        gluePlan.setPlanAmount(prodOrder.getOrderDetail().getUpperLowerGlueUsage());
        try {
            String upperLowerGlue = prodOrder.getOrderDetail().getUpperLowerGlue();
            ObjectMapper resultMapper = new ObjectMapper();
            UpperLowerGlue glue = resultMapper.readValue(upperLowerGlue, UpperLowerGlue.class);
            gluePlan.setMaterialCode(glue.getMaterialList_1().get(0).getMaterial().getMaterialNo());
            gluePlan.setMaterialName(glue.getMaterialList_1().get(0).getMaterial().getMaterialName());
        } catch (Exception e) {
            e.printStackTrace();
        }


        //输送带
        ProdPlanInfo conveyorBeltsPlan = new ProdPlanInfo();
        conveyorBeltsPlan.setOrderCode(prodOrder.getOrderCode());
        conveyorBeltsPlan.setPlanCode(PlanCodeUtils.getPlanCode());
        conveyorBeltsPlan.setPlanAmount(prodOrder.getOrderDetail().getBeltRequiredLength());
        //conveyorBeltsPlan.setMaterialCode("1000099");
        String beltLengthSpecifications = prodOrder.getOrderDetail().getBeltLengthSpecifications();
        if (beltLengthSpecifications != null && !beltLengthSpecifications.isEmpty()) {
            int spaceIndex = beltLengthSpecifications.indexOf(' ');
            if (spaceIndex != -1) {
                beltLengthSpecifications = beltLengthSpecifications.substring(0, spaceIndex);
            }
            conveyorBeltsPlan.setMaterialName(beltLengthSpecifications);
        }

        planInfoList.add(clothPlan);
        planInfoList.add(gluePlan);
        planInfoList.add(conveyorBeltsPlan);
        result.put("prodOrder", prodOrder);
        result.put("planInfoList", planInfoList);
        return result;
    }
}
