package com.os.mes.prod.service.impl;

import java.util.List;

import com.os.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.prod.mapper.ProdPlanInfoMapper;
import com.os.mes.prod.domain.ProdPlanInfo;
import com.os.mes.prod.service.IProdPlanInfoService;

import static com.os.common.utils.SecurityUtils.getUsername;

/**
 * 生产工单Service业务层处理
 *
 * @author Yinq
 * @date 2024-06-03
 */
@Service
public class ProdPlanInfoServiceImpl implements IProdPlanInfoService {
    @Autowired
    private ProdPlanInfoMapper prodPlanInfoMapper;

    /**
     * 查询生产工单
     *
     * @param objId 生产工单主键
     * @return 生产工单
     */
    @Override
    public ProdPlanInfo selectProdPlanInfoByObjId(Long objId) {
        return prodPlanInfoMapper.selectProdPlanInfoByObjId(objId);
    }

    /**
     * 查询生产工单列表
     *
     * @param prodPlanInfo 生产工单
     * @return 生产工单
     */
    @Override
    public List<ProdPlanInfo> selectProdPlanInfoList(ProdPlanInfo prodPlanInfo) {
        return prodPlanInfoMapper.selectProdPlanInfoList(prodPlanInfo);
    }

    /**
     * 新增生产工单
     *
     * @param prodPlanInfo 生产工单
     * @return 结果
     */
    @Override
    public int insertProdPlanInfo(ProdPlanInfo prodPlanInfo) {
        return prodPlanInfoMapper.insertProdPlanInfo(prodPlanInfo);
    }

    /**
     * 修改生产工单
     *
     * @param prodPlanInfo 生产工单
     * @return 结果
     */
    @Override
    public int updateProdPlanInfo(ProdPlanInfo prodPlanInfo) {
        return prodPlanInfoMapper.updateProdPlanInfo(prodPlanInfo);
    }

    /**
     * 批量删除生产工单
     *
     * @param objIds 需要删除的生产工单主键
     * @return 结果
     */
    @Override
    public int deleteProdPlanInfoByObjIds(Long[] objIds) {
        return prodPlanInfoMapper.deleteProdPlanInfoByObjIds(objIds);
    }

    /**
     * 删除生产工单信息
     *
     * @param objId 生产工单主键
     * @return 结果
     */
    @Override
    public int deleteProdPlanInfoByObjId(Long objId) {
        return prodPlanInfoMapper.deleteProdPlanInfoByObjId(objId);
    }

    /**
     * 订单新增生产工单List
     * @param prodPlanInfos
     * @return
     */
    @Override
    public int orderAddProdPlanInfoList(List<ProdPlanInfo> prodPlanInfos) {
        for (ProdPlanInfo prodPlanInfo : prodPlanInfos) {
            prodPlanInfo.setCreatedBy(getUsername());
            prodPlanInfo.setCreatedTime(DateUtils.getNowDate());
            prodPlanInfoMapper.insertProdPlanInfo(prodPlanInfo);
        }
        return 1;
    }
}
