package com.os.mes.record.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.record.domain.RecordStaffCommute;
import com.os.mes.record.service.IRecordStaffCommuteService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 员工上下班记录Controller
 *
 * @author Yinq
 * @date 2024-07-01
 */
@RestController
@RequestMapping("/mes/record/recordStaffCommute")
public class RecordStaffCommuteController extends BaseController {
    @Autowired
    private IRecordStaffCommuteService recordStaffCommuteService;

    /**
     * 查询员工上下班记录列表
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffCommute:list')")
    @GetMapping("/list")
    public TableDataInfo list(RecordStaffCommute recordStaffCommute) {
        startPage();
        List<RecordStaffCommute> list = recordStaffCommuteService.selectRecordStaffCommuteList(recordStaffCommute);
        return getDataTable(list);
    }

    /**
     * 导出员工上下班记录列表
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffCommute:export')")
    @Log(title = "员工上下班记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RecordStaffCommute recordStaffCommute) {
        List<RecordStaffCommute> list = recordStaffCommuteService.selectRecordStaffCommuteList(recordStaffCommute);
        ExcelUtil<RecordStaffCommute> util = new ExcelUtil<RecordStaffCommute>(RecordStaffCommute.class);
        util.exportExcel(response, list, "员工上下班记录数据");
    }

    /**
     * 获取员工上下班记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffCommute:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(recordStaffCommuteService.selectRecordStaffCommuteByObjId(objId));
    }

    /**
     * 新增员工上下班记录
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffCommute:add')")
    @Log(title = "员工上下班记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecordStaffCommute recordStaffCommute) {
        recordStaffCommute.setCreateBy(getUsername());
        return toAjax(recordStaffCommuteService.insertRecordStaffCommute(recordStaffCommute));
    }

    /**
     * 修改员工上下班记录
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffCommute:edit')")
    @Log(title = "员工上下班记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecordStaffCommute recordStaffCommute) {
        recordStaffCommute.setUpdateBy(getUsername());
        return toAjax(recordStaffCommuteService.updateRecordStaffCommute(recordStaffCommute));
    }

    /**
     * 删除员工上下班记录
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffCommute:remove')")
    @Log(title = "员工上下班记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(recordStaffCommuteService.deleteRecordStaffCommuteByObjIds(objIds));
    }
}
